==> ecidacli-0.0.18-py3-none-any.whl: ecidacli.py <==
import argparse
import os
import importlib
import yaml
# from Ecida import EcidaModule

dockerfile_commands = []
dockerfile_commands.append("FROM python:3.9-slim-buster")
dockerfile_commands.append("WORKDIR /app")
dockerfile_commands.append("RUN apt-get update")
dockerfile_commands.append("RUN apt-get install -y gcc")
dockerfile_commands.append("ENV PYTHONUNBUFFERED=1")
dockerfile_commands.append("COPY requirements.txt .")
dockerfile_commands.append("RUN pip install --no-cache-dir -r requirements.txt")
dockerfile_commands.append("COPY . .")

def create_deploy_docker_image(imageTag: str, mainfile:str):
    # Define the base image and working directory
    base_image = "python:3.9-slim-buster"
    workdir = "/app"

    # Define the Dockerfile commands
    dockerfile = []
    dockerfile.append(f"FROM {base_image}")
    dockerfile.append(f"WORKDIR {workdir}")
    dockerfile.append("COPY requirements.txt .")
    dockerfile.append("RUN pip install --no-cache-dir -r requirements.txt")
    dockerfile.append("COPY . .")
    dockerfile.append(f"CMD [\"python\", \"{mainfile}\"]")

    # Write the Dockerfile to disk
    with open("Dockerfile", "w") as f:
        f.write("\n".join(dockerfile))

    # Build the Docker image
    
    os.system(f"docker build -t {imageTag} .")
    os.system(f"docker push {imageTag}")
    os.remove("Dockerfile")
    

def apply_yaml(Module, imageTag:str, secret: str):
    moduleName = f"{Module.name}-{Module.version}"
    files = {}
    
    for key, git in Module.directories.items():
        files[key] = {
            "localPath": key,
        }
        if "source" in git and git["source"] != "":
            git["secret"] = secret
            files[key]["preload"] = {
                "git" : {
                    "source" : git["source"],
                    "folder" : git["folder"],
                    "secret" : git["secret"]
                }
            }
    kafka = {}
    if len(Module.topics_envVars) > 0:
        kafka = {
                    "server": "KAFKA_BOOTSTRAP_SERVER",
                    "securityProtocol": "KAFKA_SECURITY_PROTOCOL",
                    "saslMechanism": "KAFKA_SASL_MECHANISM",
                    "username": "KAFKA_USERNAME",
                    "password": "KAFKA_PASSWORD",
                    "topics": Module.topics_envVars
                }
    
    
    data = {
        "apiVersion": "ecida.org/v5alpha1",
        "kind" : "Module",
        "metadata": {
            "name": moduleName,
            "namespace": "ecida-repository",
            "labels":{
                "template" : "default"
            },
        },
        "spec":{
          "definitions": {
              "inputs": Module.inputs,
              "outputs": Module.outputs},
          "implementations":{
              "docker": {
                  "image": imageTag
              },
              "kafka":kafka,
              "file" : files,
              "env": {
                  "ECIDA_DEPLOY": "true"
              }
          }
        }
    }
    yamlFilename = f"auto_generated_{moduleName}.yaml"
    with open(yamlFilename, "w") as f:
        yaml.dump(data, f)
    
def module_path(mainfilepath: str) -> str:
    python_module_path = mainfilepath[:-3]
    python_module_path = python_module_path.replace("/", ".")
    python_module_path = python_module_path.lstrip('.')
    return python_module_path

def create_image_tag(username: str, M) -> str:
    imageTag = username + "/" + M.name + ":" + M.version
    return imageTag

def main():
    print("v0.0.18")
    # Create an ArgumentParser object
    parser = argparse.ArgumentParser(prog="ecidacli")
    parser.add_argument("-f", "--main-file", help="main file to process (example: main.py)")
    
    subparsers = parser.add_subparsers(required= True, metavar="COMMAND", title="COMMAND", dest="command")
    parser_manifests = subparsers.add_parser('manifests', help='generate the kubernetes manifests')
    parser_build = subparsers.add_parser('build', help='build the container and push it to dockerhub')
    
    # Add arguments to the parser
    parser_build.add_argument("-u", "--username", help="username for Dockerhub authentication")
    parser_manifests.add_argument("-u", "--username", help="username for Dockerhub authentication")
    parser_build.add_argument("-s", "--secret", help="name of secret in the kubernetes-cluster")
    parser_manifests.add_argument("-s", "--secret", help="name of secret in the kubernetes-cluster")

    # Parse the command line arguments
    args = parser.parse_args()
    main_file = args.main_file    
    username = args.username
    secret = args.secret
    
    
    # Import the module dynamically
    try:
        if args.command == "manifests":
            manifests(main_file, username, secret)
        elif args.command == "build":
            build(main_file, username)
            print(f"{main_file} processed successfully")
            
    except Exception as e:
        print(e)
        # print(f"{mainfile} does not contain an EcidaModule")
    
def common(main_file: str, username: str):
    python_module_path = module_path(main_file)
    module = importlib.import_module(python_module_path)
    M = module.create_module()
    imageTag = create_image_tag(username, M)
    return M, imageTag
    
def manifests(main_file: str, username: str, secret: str):
    M, imageTag = common(main_file, username)
    apply_yaml(M, imageTag, secret)
    
    
def build(main_file: str , username: str):
    M, imageTag = common(main_file, username)
    dirname = os.path.dirname(main_file)
    os.chdir(dirname)
    basefile = os.path.basename(main_file)
    create_deploy_docker_image(imageTag, basefile)
    

if __name__ == "__main__":
    main()

==> ecidacli-0.0.19-py3-none-any.whl: ecidacli.py <==
import argparse
import os
import importlib
import yaml
# from Ecida import EcidaModule

dockerfile_commands = []
dockerfile_commands.append("FROM python:3.9-slim-buster")
dockerfile_commands.append("WORKDIR /app")
dockerfile_commands.append("RUN apt-get update")
dockerfile_commands.append("RUN apt-get install -y gcc")
dockerfile_commands.append("ENV PYTHONUNBUFFERED=1")
dockerfile_commands.append("COPY requirements.txt .")
dockerfile_commands.append("RUN pip install --no-cache-dir -r requirements.txt")
dockerfile_commands.append("COPY . .")

def create_deploy_docker_image(imageTag: str, mainfile:str):
    # Define the base image and working directory
    base_image = "python:3.9-slim-buster"
    workdir = "/app"

    # Define the Dockerfile commands
    dockerfile = []
    dockerfile.append(f"FROM {base_image}")
    dockerfile.append(f"WORKDIR {workdir}")
    dockerfile.append("COPY requirements.txt .")
    dockerfile.append("RUN pip install --no-cache-dir -r requirements.txt")
    dockerfile.append("COPY . .")
    dockerfile.append(f"CMD [\"python\", \"{mainfile}\"]")

    # Write the Dockerfile to disk
    with open("Dockerfile", "w") as f:
        f.write("\n".join(dockerfile))

    # Build the Docker image
    
    os.system(f"docker build -t {imageTag} .")
    os.system(f"docker push {imageTag}")
    os.remove("Dockerfile")
    

def apply_yaml(Module, imageTag:str, secret: str):
    moduleName = f"{Module.name}-{Module.version}"
    files = {}
    
    for key, git in Module.directories.items():
        files[key] = {
            "localPath": key,
        }
        if "source" in git and git["source"] != "":
            git["secret"] = secret
            files[key]["preload"] = {
                "git" : {
                    "source" : git["source"],
                    "folder" : git["folder"],
                    "secret" : git["secret"]
                }
            }
    kafka = {}
    if len(Module.topics_envVars) > 0:
        kafka = {
                    "server": "KAFKA_BOOTSTRAP_SERVER",
                    "securityProtocol": "KAFKA_SECURITY_PROTOCOL",
                    "saslMechanism": "KAFKA_SASL_MECHANISM",
                    "username": "KAFKA_USERNAME",
                    "password": "KAFKA_PASSWORD",
                    "topics": Module.topics_envVars
                }
    
    
    data = {
        "apiVersion": "ecida.org/v5alpha1",
        "kind" : "Module",
        "metadata": {
            "name": moduleName,
            "namespace": "ecida-repository",
            "labels":{
                "template" : "default"
            },
        },
        "spec":{
          "definitions": {
              "inputs": Module.inputs,
              "outputs": Module.outputs},
          "implementations":{
              "docker": {
                  "image": imageTag
              },
              "kafka":kafka,
              "file" : files,
              "env": {
                  "ECIDA_DEPLOY": "true"
              }
          }
        }
    }
    yamlFilename = f"auto_generated_{moduleName}.yaml"
    with open(yamlFilename, "w") as f:
        yaml.dump(data, f)
        print(yamlFilename + " is generated")
    
def module_path(mainfilepath: str) -> str:
    python_module_path = mainfilepath[:-3]
    python_module_path = python_module_path.replace("/", ".")
    python_module_path = python_module_path.lstrip('.')
    return python_module_path

def create_image_tag(username: str, M) -> str:
    imageTag = username + "/" + M.name + ":" + M.version
    return imageTag

def main():
    print("v0.0.19")
    # Create an ArgumentParser object
    parser = argparse.ArgumentParser(prog="ecidacli")
    parser.add_argument("-f", "--main-file", help="main file to process (example: main.py)")
    
    subparsers = parser.add_subparsers(required= True, metavar="COMMAND", title="COMMAND", dest="command")
    parser_manifests = subparsers.add_parser('manifests', help='generate the kubernetes manifests')
    parser_build = subparsers.add_parser('build', help='build the container and push it to dockerhub')
    
    # Add arguments to the parser
    parser_build.add_argument("-u", "--username", help="username for Dockerhub authentication")
    parser_manifests.add_argument("-u", "--username", help="username for Dockerhub authentication")
    parser_build.add_argument("-s", "--secret", help="name of secret in the kubernetes-cluster")
    parser_manifests.add_argument("-s", "--secret", help="name of secret in the kubernetes-cluster")

    # Parse the command line arguments
    
    args = parser.parse_args()
    print(args)
    main_file = args.main_file    
    username = args.username
    secret = args.secret
    
    
    # Import the module dynamically
    try:
        if args.command == "manifests":
            manifests(main_file, username, secret)
        elif args.command == "build":
            build(main_file, username)
            print(f"{main_file} built successfully")
            
    except Exception as e:
        print(e)
        # print(f"{mainfile} does not contain an EcidaModule")
    
def common(main_file: str, username: str):
    python_module_path = module_path(main_file)
    module = importlib.import_module(python_module_path)
    M = module.create_module()
    imageTag = create_image_tag(username, M)
    return M, imageTag
    
def manifests(main_file: str, username: str, secret: str):
    M, imageTag = common(main_file, username)
    apply_yaml(M, imageTag, secret)
    
    
def build(main_file: str , username: str):
    M, imageTag = common(main_file, username)
    dirname = os.path.dirname(main_file)
    os.chdir(dirname)
    basefile = os.path.basename(main_file)
    create_deploy_docker_image(imageTag, basefile)
    

if __name__ == "__main__":
    main()
